Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStephen Swaney <sswaney@centurytel.net>2006-07-12 18:27:13 +0400
committerStephen Swaney <sswaney@centurytel.net>2006-07-12 18:27:13 +0400
commitaa42dc28f19a3fa0f33d9ebd3a04cebec8590631 (patch)
treec17ecdba81147888fcd16ec814c132c60f88a0a9
parentcfeaf8dfdfbb9d306803ad55301a12e13e0e44bf (diff)
more spell checking.
-rw-r--r--source/blender/python/api2_2x/doc/Material.py20
-rw-r--r--source/blender/python/api2_2x/doc/Modifier.py4
-rw-r--r--source/blender/python/api2_2x/doc/NLA.py10
-rw-r--r--source/blender/python/api2_2x/doc/NMesh.py8
-rw-r--r--source/blender/python/api2_2x/doc/Render.py22
-rw-r--r--source/blender/python/api2_2x/doc/Text3d.py30
-rw-r--r--source/blender/python/api2_2x/doc/World.py52
7 files changed, 73 insertions, 73 deletions
diff --git a/source/blender/python/api2_2x/doc/Material.py b/source/blender/python/api2_2x/doc/Material.py
index bbae407aa9f..2b161e558d4 100644
--- a/source/blender/python/api2_2x/doc/Material.py
+++ b/source/blender/python/api2_2x/doc/Material.py
@@ -68,14 +68,14 @@ Example::
@type Shaders: readonly dictionary
@var Shaders: The available Material Shaders.
- DIFFUSE_LAMBERT - Make Material use the lambert diffuse shader.
- - DIFFUSE_ORENNAYAR - Make Material use the orennayar diffuse shader.
+ - DIFFUSE_ORENNAYAR - Make Material use the Oren-Nayer diffuse shader.
- DIFFUSE_TOON - Make Material use the toon diffuse shader.
- DIFFUSE_MINNAERT - Make Material use the minnaert diffuse shader.
- - SPEC_COOKTORR - Make Material use the cooktorr specular shader.
- - SPEC_PHONG - Make Material use the phong specular shader.
- - SPEC_BLINN - Make Material use the blinn specular shader.
+ - SPEC_COOKTORR - Make Material use the Cook-Torr specular shader.
+ - SPEC_PHONG - Make Material use the Phong specular shader.
+ - SPEC_BLINN - Make Material use the Blinn specular shader.
- SPEC_TOON - Make Material use the toon specular shader.
- - SPEC_WARDISO - Make Material use the wardiso specular shader.
+ - SPEC_WARDISO - Make Material use the Ward-iso specular shader.
"""
def New (name = 'Mat'):
@@ -209,7 +209,7 @@ class Material:
@type nStars: int
@ivar name: Material data name.
@type name: str
- @ivar oopsLoc: Material OOPs location. Returns None if materal not found in list.
+ @ivar oopsLoc: Material OOPs location. Returns None if material not found in list.
@type oopsLoc: list of 2 floats
@ivar oopsSel: Material OOPs selection flag.
Value must be in the range [0,1].
@@ -538,14 +538,14 @@ class Material:
def setSpecSize(specSize):
"""
- Set the material's size of speculara area (applies to the \"Toon\" Specular Shader only)
+ Set the material's size of specular area (applies to the \"Toon\" Specular Shader only)
@type specSize: float
@param specSize: The new value in [0.0, 1.53].
"""
def getSpecSize():
"""
- Get the material's size of speculara area (applies to the \"Toon\" Specular Shader only)
+ Get the material's size of specular area (applies to the \"Toon\" Specular Shader only)
@rtype specSize: float
"""
@@ -934,9 +934,9 @@ class Material:
@type texture: Blender Texture
@param texture: a Blender Texture object.
@type texco: int
- @param texco: optional or'ed bitflag -- defaults to TexCo.ORCO. See TexCo var in L{Texture}.
+ @param texco: optional ORed bitflag -- defaults to TexCo.ORCO. See TexCo var in L{Texture}.
@type mapto: int
- @param mapto: optional or'ed bitflag -- defaults to MapTo.COL. See MapTo var in L{Texture}.
+ @param mapto: optional ORed bitflag -- defaults to MapTo.COL. See MapTo var in L{Texture}.
"""
def clearTexture(index):
diff --git a/source/blender/python/api2_2x/doc/Modifier.py b/source/blender/python/api2_2x/doc/Modifier.py
index cf4731d9813..3aac3ae880e 100644
--- a/source/blender/python/api2_2x/doc/Modifier.py
+++ b/source/blender/python/api2_2x/doc/Modifier.py
@@ -116,7 +116,7 @@ class Modifiers:
"""
Moves the modifier up in the object's modifier stack.
@type modifier: a modifier from this sequence to remove.
- @rtype: PyNone
+ @rtype: None
@raise RuntimeError: request to move above another modifier requiring
original data
@note: Accessing attributes of the modifier after removing will raise an error.
@@ -126,7 +126,7 @@ class Modifiers:
"""
Moves the modifier down in the object's modifier stack.
@type modifier: a modifier from this sequence to remove.
- @rtype: PyNone
+ @rtype: None
@raise RuntimeError: request to move modifier beyond a non-deforming
modifier
@note: Accessing attributes of the modifier after removing will raise an error.
diff --git a/source/blender/python/api2_2x/doc/NLA.py b/source/blender/python/api2_2x/doc/NLA.py
index 22c63bec92c..9883528520b 100644
--- a/source/blender/python/api2_2x/doc/NLA.py
+++ b/source/blender/python/api2_2x/doc/NLA.py
@@ -60,7 +60,7 @@ Example::
@var Flags: Constant dict used by the L{ActionStrip.flag} attribute.
It is a bitmask and settings are ORed together.
- SELECT: action strip is selected in NLA window
- - STRIDE_PATH: play action nased on path position and stride.
+ - STRIDE_PATH: play action based on path position and stride.
- HOLD: continue displaying the last frame past the end of the strip
- ACTIVE: action strip is active in NLA window
- LOCK_ACTION: action start/end are automatically mapped to strip duration
@@ -182,7 +182,7 @@ class ActionStrips:
def append(action):
"""
- Appends a new action to the end of the actionstrip sequence.
+ Appends a new action to the end of the action strip sequence.
@type action: L{Action<NLA.Action>}
@param action: the action to use in the action strip
@rtype: Constraint
@@ -252,14 +252,14 @@ class ActionStrip:
Start/End". This method restores the values of ActionStart and
ActionEnd to their defaults, usually the first and last frames within
an action that contain keys.
- @rtype: PyNone
+ @rtype: None
"""
def resetStripSize():
"""
Activates the functionality found in NLA Strip menu under "Reset Strip
Size". This method resets the Action Strip size to its creation values.
- @rtype: PyNone
+ @rtype: None
"""
def snapToFrame():
@@ -267,5 +267,5 @@ class ActionStrip:
Activates the functionality found in NLA Strip menu under "Snap to Frame".
This function snaps the ends of the action strip to the nearest whole
numbered frame.
- @rtype: PyNone
+ @rtype: None
"""
diff --git a/source/blender/python/api2_2x/doc/Text3d.py b/source/blender/python/api2_2x/doc/Text3d.py
index c130b562fb4..7878221d0a1 100644
--- a/source/blender/python/api2_2x/doc/Text3d.py
+++ b/source/blender/python/api2_2x/doc/Text3d.py
@@ -62,7 +62,7 @@ class Text3d:
Set the name of this Text3d object.
@type name: string
@param name: The new name.
- @returns: PyNone
+ @returns: None
"""
def getText():
@@ -76,7 +76,7 @@ class Text3d:
Set the text string in this Text3d object
@type name: string
@param name: The new text string for this object.
- @returns: PyNone
+ @returns: None
"""
def getDrawMode():
@@ -95,7 +95,7 @@ class Text3d:
- DRAW3D
- DRAWFRONT
- DRAWBACK
- @rtype: PyNone
+ @rtype: None
@type val: single module constant or tuple of module constants
@param val : The Text3d's modes. See L{getDrawMode} for the meaning of
the constants.
@@ -120,7 +120,7 @@ class Text3d:
def setBevelAmount(bevelresol):
"""
Set the Text3d's bevel resolution value.
- @rtype: PyNone
+ @rtype: None
@type bevelresol: float
@param bevelresol: The new Curve's bevel resolution value.
"""
@@ -134,7 +134,7 @@ class Text3d:
def setDefaultResolution(resolu):
"""
Sets Default text Resolution.
- @rtype: PyNone
+ @rtype: None
@type resolu: float
@param resolu: The new Curve's U-resolution value.
"""
@@ -148,7 +148,7 @@ class Text3d:
def setWidth(width):
"""
Set the Text3d's width value.
- @rtype: PyNone
+ @rtype: None
@type width: float
@param width: The new text3d's width value.
"""
@@ -162,7 +162,7 @@ class Text3d:
def setgetExtrudeDepth(ext1):
"""
Set the text3d's ext1 value.
- @rtype: PyNone
+ @rtype: None
@type ext1: float
@param ext1: The new text3d's ext1 value.
"""
@@ -176,7 +176,7 @@ class Text3d:
def setExtrudeBevelDepth(ext2):
"""
Set the text3d's ext2 value.
- @rtype: PyNone
+ @rtype: None
@type ext2: float
@param ext2: The new text3d's ext2 value.
"""
@@ -190,7 +190,7 @@ class Text3d:
def setShear(shear):
"""
Set the text3d's shear value.
- @rtype: PyNone
+ @rtype: None
@type shear: float
@param shear: The new text3d's shear value.
"""
@@ -204,7 +204,7 @@ class Text3d:
def setSize(size):
"""
Set the text3d's size value.
- @rtype: PyNone
+ @rtype: None
@type size: float
@param size: The new text3d's size value.
"""
@@ -218,7 +218,7 @@ class Text3d:
def setLineSeparation(sep):
"""
Set the text3d's ext2 value.
- @rtype: PyNone
+ @rtype: None
@type sep: float
@param sep: The new text3d's separation value.
"""
@@ -232,7 +232,7 @@ class Text3d:
def setSpacing(spacing):
"""
Set the text3d's spacing value.
- @rtype: PyNone
+ @rtype: None
@type spacing: float
@param spacing: The new text3d's spacing value.
"""
@@ -246,7 +246,7 @@ class Text3d:
def setXoffset(xof):
"""
Set the text3d's Xoffset value.
- @rtype: PyNone
+ @rtype: None
@type xof: float
@param xof: The new text3d's Xoffset value.
"""
@@ -260,7 +260,7 @@ class Text3d:
def setYoffset(yof):
"""
Set the text3d's Yoffset value.
- @rtype: PyNone
+ @rtype: None
@type yof: float
@param yof: The new text3d's Yoffset value.
"""
@@ -282,7 +282,7 @@ class Text3d:
- RIGHT
- MIDDLE
- FLUSH
- @rtype: PyNone
+ @rtype: None
@type align: module constant
@param align: The new text3d's Alignment value.
"""
diff --git a/source/blender/python/api2_2x/doc/World.py b/source/blender/python/api2_2x/doc/World.py
index a8fe12b7605..41d5d8aa506 100644
--- a/source/blender/python/api2_2x/doc/World.py
+++ b/source/blender/python/api2_2x/doc/World.py
@@ -21,7 +21,7 @@ Example::
import Blender
from Blender import *
- AllWorlds = Blender.World.Get() # returns a list of created world obejcts
+ AllWorlds = Blender.World.Get() # returns a list of created world objects
AvailWorlds = len(AllWorlds) # returns the number of available world objects
PropWorld = dir(AllWorlds[0]) # returns the properties of the class world
NameWorld = AllWorlds[0].getName() # get name of the first world object
@@ -32,8 +32,8 @@ Example::
HorColor = AllWorlds[0].getHor() # horizon color of the first world object
HorColorR = HorColor[0] # get the red channel (RGB) of the horizon color
- ZenColor = AllWorlds[0].getZen() # zenit color of the first world object
- ZenColorB = ZenColor[2] # get the blue channel (RGB) of the Zenit color
+ ZenColor = AllWorlds[0].getZen() # zenith color of the first world object
+ ZenColorB = ZenColor[2] # get the blue channel (RGB) of the Zenith color
blending = AllWorlds[0].getSkytype() # get the blending modes (real, blend, paper) of the first world object
"""
@@ -42,7 +42,7 @@ def New (name):
"""
Creates a new World.
@type name: string
- @param name: World's name (optionnal).
+ @param name: World's name (optional).
@rtype: Blender World
@return: The created World. If the "name" parameter has not been provided, it will be automatically be set by blender.
"""
@@ -97,8 +97,8 @@ class World:
Sets the range parameter of a world object.
@type range: float
@param range: the new range parameter
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getName():
@@ -113,8 +113,8 @@ class World:
Sets the name of a world object.
@type name: string
@param name : the new name.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getIpo():
@@ -151,8 +151,8 @@ class World:
See getSkytype for the semantics of the parameter.
@type skytype: int
@param skytype : the new skytype.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getMode():
@@ -173,8 +173,8 @@ class World:
See getMode for the semantics of the parameter.
@type mode: int
@param mode : the new mode.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getMistype():
@@ -191,8 +191,8 @@ class World:
See getMistype for the semantics of the parameter.
@type mistype: int
@param mistype : the new mist type.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getHor():
@@ -208,8 +208,8 @@ class World:
Sets the horizon color of a world object.
@type hor: list of three floats
@param hor : the new hor.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getZen():
@@ -225,8 +225,8 @@ class World:
Sets the zenith color of a world object.
@type zen: list of three floats
@param zen : the new zenith color.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getAmb():
@@ -242,8 +242,8 @@ class World:
Sets the ambient color of a world object.
@type amb: list of three floats
@param amb : the new ambient color.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getStar():
@@ -267,8 +267,8 @@ class World:
See getStar for the semantics of the parameter.
@type star: list of 9 floats
@param star : the new star parameters.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getMist():
@@ -289,8 +289,8 @@ class World:
See getMist for the semantics of the parameter.
@type mist: list of 4 floats
@param mist : the new mist parameters.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def getScriptLinks (event):
@@ -323,8 +323,8 @@ class World:
def setCurrent ():
"""
Make this world active in the current scene.
- @rtype: PyNone
- @return: PyNone
+ @rtype: None
+ @return: None
"""
def insertIpoKey(keytype):
diff --git a/source/blender/python/api2_2x/doc/NMesh.py b/source/blender/python/api2_2x/doc/NMesh.py
index 8b434a7aacb..a11d8fabeba 100644
--- a/source/blender/python/api2_2x/doc/NMesh.py
+++ b/source/blender/python/api2_2x/doc/NMesh.py
@@ -72,7 +72,7 @@ Example::
- TILES - uses tiled image.
- TWOSIDE - two-sided face.
@var FaceTranspModes: The available face transparency modes. Note: these are
- enumerated values (enums), they can't be combined (and'ed, or'ed, etc) like a bit vector.
+ enumerated values (enums), they can't be combined (ANDed, ORed, etc) like a bit vector.
- SOLID - draw solid.
- ADD - add to background (halo).
- ALPHA - draw with transparency.
@@ -433,7 +433,7 @@ class NMesh:
Get this NMesh's list of materials.
@type what: int
@param what: determines the list's contents:
- - -1: return the current nmesh's list;
+ - -1: return the current NMesh's list;
- 0: retrieve a fresh list from the Blender mesh -- eventual
modifications made by the script not included, unless
L{update} is called before this method;
@@ -652,7 +652,7 @@ class NMesh:
"""
Get this mesh's mode flags.
@rtype: int
- @return: Or'ed value. See L{Modes}.
+ @return: ORed value. See L{Modes}.
"""
def setMode(m=None, m1=None, m2=None):
@@ -724,7 +724,7 @@ class NMesh:
@type assignmode: string
@param assignmode: Three choices:
- 'add'
- - 'substract'
+ - 'subtract'
- 'replace'\n
'B{add}': if the vertex in the list is not assigned to the group
diff --git a/source/blender/python/api2_2x/doc/Render.py b/source/blender/python/api2_2x/doc/Render.py
index 4fa6d2945b0..9a237cc0679 100644
--- a/source/blender/python/api2_2x/doc/Render.py
+++ b/source/blender/python/api2_2x/doc/Render.py
@@ -439,7 +439,7 @@ class RenderData:
def enableOversampling(toggle):
"""
- Enable/disable oversampling (anit-aliasing).
+ Enable/disable oversampling (anti-aliasing).
@type toggle: int
@param toggle: pass 1 for on / 0 for off
"""
@@ -497,7 +497,7 @@ class RenderData:
def enableKey():
"""
- Enable alpha and colour values remain unchanged.
+ Enable alpha and color values remain unchanged.
"""
def enableShadow(toggle):
@@ -572,7 +572,7 @@ class RenderData:
def enableGaussFilter(toggle):
"""
Enable/disable Gauss sampling filter for antialiasing.
@type toggle: int
@param toggle: pass 1 for on / 0 for off
"""
@@ -691,15 +691,15 @@ class RenderData:
Set the type of image to output from the render.
@type type: enum constant
@param type: must be one of 13 constants:
- - AVIRAW: Uncompressed AVI files. AVI is a commonly used format on Windows plattforms
- - AVIJPEG: AVI movie w/ Jpeg images
+ - AVIRAW: Uncompressed AVI files. AVI is a commonly used format on Windows platforms
+ - AVIJPEG: AVI movie w/ JPEG images
- AVICODEC: AVI using win32 codec
- QUICKTIME: Quicktime movie (if enabled)
- TARGA: Targa files
- RAWTGA: Raw Targa files
- PNG: Png files
- BMP: Bitmap files
- - JPEG90: Jpeg files
+ - JPEG90: JPEG files
- HAMX: Hamx files
- IRIS: Iris files
- IRIZ: Iris + z-buffer files
@@ -708,7 +708,7 @@ class RenderData:
def quality(qual = None):
"""
- Get/set quality get/setting for JPEG images, AVI Jpeg and SGI movies.
+ Get/set quality get/setting for JPEG images, AVI JPEG and SGI movies.
@type qual: int (optional)
@param qual: must be between 10 - 100
@rtype: int (if prototype is empty)
@@ -726,7 +726,7 @@ class RenderData:
def enableGrayscale():
"""
- Images are saved with BW (grayscale) data.
+ Images are saved with black and white (grayscale) data.
"""
def enableRGBColor():
@@ -779,7 +779,7 @@ class RenderData:
Set yafray global Illumination method.
@type type: enum constant
@param type: must be one of 3 constants:
- - NONE: Dont use GI illumination
+ - NONE: Do not use GI illumination
- SKYDOME: Use Skydome method
- GIFULL: Use Full method
"""
@@ -873,7 +873,7 @@ class RenderData:
def enableYafrayGITunePhotons(toggle):
"""
- Enable/disable show the photonmap directly in the render for tuning.
+ Enable/disable show the photon map directly in the render for tuning.
YafrayMethod must be GIFULL and Photons enabled.
@type toggle: int
@param toggle: pass 1 for on / 0 for off
@@ -964,7 +964,7 @@ class RenderData:
def enableGameFrameStretch():
"""
- Enble stretch or squeeze the viewport to fill the display window.
+ Enable stretch or squeeze the viewport to fill the display window.
"""
def enableGameFrameExpose():
@@ -572,7 +572,7 @@ class RenderData:
def enableGaussFilter(toggle):
"""
- Enable/disable Gauss sampling filter for antialiasing.
+ Enable/disable Gauss sampling filter for anti-aliasing.